Exandra.UDT (exandra v1.0.0)

Copy Markdown View Source

Ecto.ParameterizedType for User-Defined Types (UDTs).

Options

  • :type (atom/0) - Required. The UDT.

  • :encoded_fields (list of atom/0) - JSON encoded fields.

Examples

For example, if you have defined an email UDT in your database, you can use it in your schema like this:

schema "users" do
  field :email, Exandra.UDT, type: :email
end

Summary

Types

t()

@type t() :: map()